@@ -18,33 +18,46 @@
 #' @param tit (character) custom title
 #' @param xLim (numerical,length=2) custom x-axis limits
 #' @param silent (logical) suppress messages
+#' @param debug (logical) additional messages for debugging 
 #' @param callFrom (character) allow easier tracking of messages produced
-#' @return This function produces graphics only
+#' @return This function produces a graphic (to the current graphical device)
 #' @seealso  \code{\link[graphics]{hist}}, \code{\link[stats]{na.fail}}, \code{\link[wrMisc]{naOmit}} 
 #' @examples
 #' set.seed(2013)
-#' datT6 <- matrix(round(rnorm(300)+3,1),ncol=6,dimnames=list(paste("li",1:50,sep=""),letters[19:24]))
-#' datT6 <- datT6 +matrix(rep(1:nrow(datT6),ncol(datT6)),ncol=ncol(datT6))
+#' datT6 <- matrix(round(rnorm(300)+3,1), ncol=6, 
+#'   dimnames=list(paste("li",1:50,sep=""), letters[19:24]))
+#' datT6 <- datT6 +matrix(rep(1:nrow(datT6),ncol(datT6)), ncol=ncol(datT6))
 #' datT6[6:7,c(1,3,6)] <- NA
 #' datT6[which(datT6 < 11 & datT6 > 10.5)] <- NA
 #' datT6[which(datT6 < 6 & datT6 > 5)] <- NA
 #' datT6[which(datT6 < 4.6 & datT6 > 4)] <- NA
-#' matrixNAinspect(datT6,gr=gl(2,3)) 
+#' matrixNAinspect(datT6, gr=gl(2,3)) 
 #' @export
-matrixNAinspect <- function(dat, gr, retnNA=TRUE, xLab=NULL, tit=NULL, xLim=NULL, silent=FALSE, callFrom=NULL) {
+matrixNAinspect <- function(dat, gr=NULL, retnNA=TRUE, xLab=NULL, tit=NULL, xLim=NULL, silent=FALSE, debug=FALSE, callFrom=NULL) {
   fxNa <- wrMisc::.composeCallName(callFrom, newNa="matrixNAinspect")
-  if(length(dim(dat)) !=2) stop("'dat' must be matrix or data.frame with >1 columns")
   if(!isTRUE(silent)) silent <- FALSE
+  if(isTRUE(debug)) silent <- FALSE else debug <- FALSE
+  ## extract if object
+  if(is.list(dat)) {
+    if("sampleSetup" %in% names(dat) & length(gr) <1) {
+      gr <- dat$sampleSetup$lev
+      if(length(gr) >1 & length(dat$sampleSetup$col) <2) names(gr) <- dat$sampleSetup$meta[,dat$sampleSetup$col]  # in case names are not provided
+    }
+    if(!silent) message(fxNa,"Trying to extract quantitation data to use as 'dat' out of list ..")
+    dat <- dat$quant }
+  
+  if(any(length(dim(dat)) !=2, dim(dat) < 2, na.rm=TRUE)) stop("Invalid argument 'dat'; must be matrix or data.frame with min 2 lines and 2 cols")
   if(is.data.frame(dat)) dat <- as.matrix(dat)
+  chGr <- FALSE
   if(length(gr) != ncol(dat)) stop("Number of columns in 'dat' and number of (group-)elements in 'gr' do not match !")
-  if(length(gr)==length(unique(gr))) { hasNaNeigh <- TRUE
+  if(length(gr)==length(unique(gr))) { hasNaNeigh <- FALSE
     if(!silent) message(fxNa,"NOTE : The argument 'gr' does not designate any replicates, can't determine NA-neighbours !")
-  } else hasNaNeigh <- FALSE
+  } else hasNaNeigh <- TRUE
   
   if(!is.factor(gr)) gr <- as.factor(gr)
   if(is.null(xLab)) xLab <- "(log2) Abundance"
   chRColB <- requireNamespace("RColorBrewer", quietly=TRUE) 
-  if(!chRColB) message(fxNa," More/better colors may be displayed with package 'RColorBrewer' installed; consider installing it !")
+  if(!chRColB) message(fxNa,"More/better colors may be displayed with package 'RColorBrewer' installed; consider installing it !")
   quaCol <- if(chRColB) RColorBrewer::brewer.pal(4,"Set1")[c(3,2,4)] else c(3:4,2) 
   if(is.null(tit)) tit <- "Distribution of values and NA-neighbours"
   cexMain <- if(nchar(tit) < 25) 1.4 else 1.1
@@ -52,25 +65,29 @@ matrixNAinspect <- function(dat, gr, retnNA=TRUE, xLab=NULL, tit=NULL, xLim=NULL
   NAneig <- NAneig2 <- numeric() 
   isNA <- is.na(dat)
   chNA <- any(isNA)
-  nNAmat <- matrix(0,nrow=nrow(dat), ncol=length(levels(gr)), dimnames=list(NULL,levels(gr)))
+  nNAmat <- matrix(0, nrow=nrow(dat), ncol=length(levels(gr)), dimnames=list(NULL,levels(gr)))
   colPanel <- c(grDevices::grey(0.6), grDevices::rgb(0,0.7,0,0.6), grDevices::rgb(0.15,0.15,0.7,0.7))
+  if(debug) {message(fxNa,"found ",sum(isNA,na.rm=TRUE)," NAs (out of ",prod(dim(dat))," values); chNA=",chNA,"   mMNi0"); 
+    mMNi0 <- list(dat=dat,gr=gr,isNA=isNA,chNA=chNA,nNAmat=nNAmat,hasNaNeigh=hasNaNeigh)}
   if(chNA & hasNaNeigh) {
+    ## extract NA-neighbours
     for(i in c(1:length(levels(gr)))) {
       curCol <- which(gr==levels(gr)[i]) 
       nNAmat[,i] <- if(length(curCol) >1) rowSums(isNA[,curCol]) else (isNA[,curCol])    
       maxCol <- length(curCol)
       useLi <- which(nNAmat[,i] >0 & nNAmat[,i] < maxCol)           # 1 or 2 NAs  (but not all)
       useL2 <- which(nNAmat[,i] >1 & nNAmat[,i] < maxCol)           # just 2 NAs  (but not all)
-      if(length(useLi) >0) NAneig <- c(NAneig,wrMisc::naOmit(as.numeric(dat[useLi,curCol])))
-      if(length(useL2) >0) NAneig2 <- c(NAneig2,wrMisc::naOmit(as.numeric(dat[useL2,curCol])))
+      if(length(useLi) >0) NAneig <- c(NAneig, wrMisc::naOmit(as.numeric(dat[useLi,curCol])))
+      if(length(useL2) >0) NAneig2 <- c(NAneig2, wrMisc::naOmit(as.numeric(dat[useL2,curCol])))
       }
     n <- c(sum(!is.na(dat)), length(NAneig), length(NAneig2))
     perc <- c("",paste(" (",round(100*n[2:3]/n[1],1),"%)"))
+    if(debug) {message(fxNa,"mMNi1  n=",wrMisc::pasteC(n))}
     hi1 <- graphics::hist(dat, breaks="FD", plot=FALSE)
     if(is.null(xLim)) graphics::plot(hi1, border=grDevices::grey(0.85), col=grDevices::grey(0.92), xlab=xLab, las=1, main=tit, cex.main=cexMain) else {
-      graphics::plot(hi1,border=grDevices::grey(0.85),col=grDevices::grey(0.92),xlab=xLab,las=1,main=tit,xlim=xLim,cex.main=cexMain)}
+      graphics::plot(hi1, border=grDevices::grey(0.85), col=grDevices::grey(0.92), xlab=xLab, las=1, main=tit, xlim=xLim,cex.main=cexMain)}
     graphics::abline(v=stats::quantile(dat,c(0.05,0.1,0.15),na.rm=TRUE), col=c(quaCol[-1],"tomato3"), lty=2)
-    graphics::mtext(paste(c(" (bar) all data",paste(" (box) ",c("any","min 2")," NA-neighbour values"))," n=",n,perc),col=colPanel[1:3],cex=0.65,adj=0,line=c(0.6,-0.1,-0.7),side=3)
+    graphics::mtext(paste(c(" (bar) all data",paste(" (box) ",c("any","min 2")," NA-neighbour values"))," n=",n,perc), col=colPanel[1:3],cex=0.65,adj=0,line=c(0.6,-0.1,-0.7),side=3)
     graphics::mtext(paste(" - -",c(5,10,15),"%-quantile (all data)"), col=c(quaCol[-1],"tomato3"), cex=0.6, adj=0, line=c(-1.5,-2.1,-2.7), side=3)
     if(length(NAneig) >10) {    # display mode
       yLim <- signif(graphics::par("usr")[3:4], 3)             # current y-limits
@@ -78,12 +95,12 @@ matrixNAinspect <- function(dat, gr, retnNA=TRUE, xLab=NULL, tit=NULL, xLim=NULL
       graphics::mtext(paste(" (arrow) mode of",if(length(NAneig2) >300) "2-"," NA-neighbours :",signif(mod,3)), col="sienna2", cex=0.7, adj=0, line=-3.4, side=3)
       graphics::arrows(mod, yLim[1]+(yLim[2]-yLim[1])*0.4, mod, yLim[1]+(yLim[2]-yLim[1])/4, length=0.1, col="sienna2", lwd=2)
     }    
-    graphics::hist(NAneig,breaks=hi1$breaks,border=grDevices::grey(0.75), col=grDevices::rgb(0.1,1,0.1,0.15), add=TRUE);                    # in green
-    graphics::hist(NAneig2,breaks=hi1$breaks,border=grDevices::grey(0.75), col=grDevices::rgb(0,0,0.7,0.2), add=TRUE);                      # in purple
+    graphics::hist(NAneig, breaks=hi1$breaks, border=grDevices::grey(0.75), col=grDevices::rgb(0.1,1,0.1,0.15), add=TRUE);                    # in green
+    graphics::hist(NAneig2, breaks=hi1$breaks, border=grDevices::grey(0.75), col=grDevices::rgb(0,0,0.7,0.2), add=TRUE);                      # in purple
     
   } else {
-    graphics::hist(dat, breaks="FD",border=grDevices::grey(0.85),col=grDevices::grey(0.92),xlab=xLab,las=1,main=tit,cex.main=cexMain)
-    graphics::mtext(paste(" (bar) all data  n=",length(dat)),col=colPanel[1], cex=0.7, adj=0, line=0.6, side=3)
+    graphics::hist(dat, breaks="FD", border=grDevices::grey(0.85), col=grDevices::grey(0.92), xlab=xLab, las=1,main=tit,cex.main=cexMain)
+    graphics::mtext(paste(" (bar) all data  n=",length(dat)), col=colPanel[1], cex=0.7, adj=0, line=0.6, side=3)
     graphics::abline(v=stats::quantile(dat,c(0.05,0.1,0.15),na.rm=TRUE), col=c(quaCol[-1],"tomato3"), lty=2) 
     graphics::mtext(paste(" - -",c(5,10,15),"%-quantile (all data)"), col=c(quaCol[-1],"tomato3"), cex=0.6, adj=0, line=c(-1.5,-2.1,-2.7), side=3)}
 }
